@@ -9,23 +9,18 @@ config = Config.getConfig(parentKey='core', key='Logger')
 
 
 import logging
-
-# create logger with 'spam_application'
 logger = logging.getLogger('hackingtools')
-logger.setLevel(logging.DEBUG)
-# create file handler which logs even debug messages
-fh = logging.FileHandler('hackingtools.log')
-fh.setLevel(logging.DEBUG)
-# create console handler with a higher log level
-ch = logging.StreamHandler()
-ch.setLevel(logging.ERROR)
-# create formatter and add it to the handlers
-formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-fh.setFormatter(formatter)
-ch.setFormatter(formatter)
-# add the handlers to the logger
-logger.addHandler(fh)
-logger.addHandler(ch)
+# Prevent multiple instances
+if not logger.handlers:
+    logger.setLevel(logging.DEBUG)
+    # create file handler which logs even debug messages
+    fh = logging.FileHandler('hackingtools.log')
+    fh.setLevel(logging.DEBUG)
+    # create formatter and add it to the handlers
+    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    fh.setFormatter(formatter)
+    # add the handlers to the logger
+    logger.addHandler(fh)
 
 __colorama.init()
 
@@ -143,15 +138,17 @@ def printMessage(message, description=None, debug_module=False, debug_core=False
         msg = '{methodCalledFrom} - {message} - {description}'.format(methodCalledFrom=methodCalledFrom, message=message, description=description)
     else:
         msg = '{methodCalledFrom} - {message}'.format(methodCalledFrom=methodCalledFrom, message=message)
-
+    
     if is_error:
         logger.critical(msg)
-    if is_info:
+    elif is_info:
         logger.info(msg)
-    if is_success:
+    elif is_success:
         logger.debug(msg)
-    if is_warn:
+    elif is_warn:
         logger.warning(msg)
+    else:
+        logger.debug(msg)
 
     if (color == __Fore.YELLOW or is_warn):
         msg = '{e} - {m}'.format(e=warn_flag, m=msg)
